==> com.liferay.commerce.term.service-1.0.8-sources.jar: com/liferay/commerce/term/internal/entry/type/PaymentTermsCommerceTermEntryType.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.commerce.term.internal.entry.type;

import com.liferay.commerce.term.constants.CommerceTermEntryConstants;
import com.liferay.commerce.term.entry.type.CommerceTermEntryType;
import com.liferay.portal.kernel.language.LanguageUtil;
import com.liferay.portal.kernel.util.ResourceBundleUtil;

import java.util.Locale;
import java.util.ResourceBundle;

import org.osgi.service.component.annotations.Component;

/**
 * @author Alessio Antonio Rendina
 */
@Component(
	enabled = false, immediate = true,
	property = "commerce.term.entry.type.key=" + CommerceTermEntryConstants.TYPE_PAYMENT_TERMS,
	service = CommerceTermEntryType.class
)
public class PaymentTermsCommerceTermEntryType
	implements CommerceTermEntryType {

	@Override
	public String getKey() {
		return CommerceTermEntryConstants.TYPE_PAYMENT_TERMS;
	}

	@Override
	public String getLabel(Locale locale) {
		ResourceBundle resourceBundle = ResourceBundleUtil.getBundle(
			"content.Language", locale, getClass());

		return LanguageUtil.get(
			resourceBundle, CommerceTermEntryConstants.TYPE_PAYMENT_TERMS);
	}

}

==> com.liferay.commerce.term.service-1.0.26-sources.jar: com/liferay/commerce/term/internal/entry/type/PaymentTermsCommerceTermEntryType.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.commerce.term.internal.entry.type;

import com.liferay.commerce.term.constants.CommerceTermEntryConstants;
import com.liferay.commerce.term.entry.type.CommerceTermEntryType;
import com.liferay.portal.kernel.language.Language;
import com.liferay.portal.kernel.util.ResourceBundleUtil;

import java.util.Locale;
import java.util.ResourceBundle;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Alessio Antonio Rendina
 */
@Component(
	enabled = false, immediate = true,
	property = "commerce.term.entry.type.key=" + CommerceTermEntryConstants.TYPE_PAYMENT_TERMS,
	service = CommerceTermEntryType.class
)
public class PaymentTermsCommerceTermEntryType
	implements CommerceTermEntryType {

	@Override
	public String getKey() {
		return CommerceTermEntryConstants.TYPE_PAYMENT_TERMS;
	}

	@Override
	public String getLabel(Locale locale) {
		ResourceBundle resourceBundle = ResourceBundleUtil.getBundle(
			"content.Language", locale, getClass());

		return _language.get(
			resourceBundle, CommerceTermEntryConstants.TYPE_PAYMENT_TERMS);
	}

	@Reference
	private Language _language;

}
